<?php

namespace Lavalite\Plan\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Lavalite\Plan\Interfaces\SubscriptionRepositoryInterface;

class SubscriptionPublicController extends BaseController
{
    // use SubscriptionWorkflow;

    /**
     * Constructor.
     *
     * @param type \Lavalite\Subscription\Interfaces\SubscriptionRepositoryInterface $subscription
     *
     * @return type
     */
    public function __construct(SubscriptionRepositoryInterface $subscription)
    {
        $this->repository = $subscription;
        parent::__construct();
    }

    /**
     * Show subscription's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $subscriptions = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$plan::$subscription.names'))
            ->view('$plan::public.subscription.index')
            ->data(compact('$subscriptions'))
            ->output();
    }

    /**
     * Show subscription's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $subscriptions = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$plan::$subscription.names'))
            ->view('$plan::public.subscription.index')
            ->data(compact('$subscriptions'))
            ->output();
    }

    /**
     * Show subscription.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $subscription = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$subscription->name . trans('$plan::$subscription.name'))
            ->view('$plan::public.subscription.show')
            ->data(compact('$subscription'))
            ->output();
    }

}
